@@ -4,8 +4,9 @@ use warnings;
 use strict;
 use DateTime();
 use DateTime::Event::Cron();
+use DateTime::Event::Cron::Quartz();
 use AnyEvent();
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 #===================================
 sub new {
@@ -13,18 +14,21 @@ sub new {
     my ( $class, %params ) = @_;
 
     foreach my $key ( keys %params ) {
-    	die "Unknown param '$key'" unless $key eq 'time_zone';
+    	die "Unknown param '$key'" unless $key =~ /^(time_zone|quartz)$/;
     }
 
     $params{time_zone} = DateTime::TimeZone->new(name => $params{time_zone})
         if $params{time_zone};
 
+    $params{quartz} //= 0;
+
     return bless {
         _jobs      => {},
         _debug     => 0,
         _id        => 0,
         _running   => 0,
         _time_zone => $params{time_zone},
+        _quartz    => $params{quartz},
     }, $class;
 }
 
@@ -49,7 +53,14 @@ sub add {
         die "No callback found for cron entry '$cron'"
             unless $cb;
 
-        my $event = DateTime::Event::Cron->new($cron);
+        my $event;
+        if ($self->{_quartz}) {
+            $event = DateTime::Event::Cron::Quartz->new($cron);
+        }
+        else {
+            $event = DateTime::Event::Cron->new($cron);
+        }
+
         my $id    = ++$self->{_id};
         $params{name} ||= $id;
         my $job = $self->{_jobs}{$id} = {
@@ -137,7 +148,14 @@ sub _schedule {
 
     for my $job (@_) {
         my $name       = $job->{name};
-        my $next_run   = $job->{event}->next($now);
+
+        my $next_run;
+        if ($self->{_quartz}) {
+            $next_run = $job->{event}->get_next_valid_time_after($now);
+        }
+        else {
+            $next_run = $job->{event}->next($now);
+        }
 
         $next_run->set_time_zone($time_zone) if $time_zone;
 
@@ -200,7 +218,7 @@ AnyEvent::DateTime::Cron - AnyEvent crontab with DateTime::Event::Cron
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -245,11 +263,19 @@ any running cron jobs to finish before exiting.
 
     $cron = AnyEvent::DateTime::Cron->new(
         time_zone => ...
+        quartz    => 0/1
     );
 
-Creates a new L<AnyEvent::DateTime::Cron> instance - takes an optional
-time_zone parameter that will be used to set the time_zone for any DateTime
-objects that are used internally.
+Creates a new L<AnyEvent::DateTime::Cron> instance - takes optional parameters
+time_zone and quartz.
+
+time_zone can will be used to set the time_zone for any DateTime objects that
+are used internally.
+
+if quartz is set to a true value then this class will use switch to using
+L<DateTime::Event::Cron::Quartz> internally, which will allow the use of seconds
+in the cron expression. See the DateTime::Event::Cron::Quartz for details on
+writing a proper quartz cron expression.
 
 =head2 add()
 
@@ -336,10 +362,20 @@ until your job has completed:
 Callbacks are called inside an C<eval> so if they throw an error, they
 will warn, but won't cause the cron loop to exit.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Clinton Gormley <drtech@cpan.org>
 
+=item *
+
+Andy Gorman <agorman@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Clinton Gormley.
